package com.example.remor.exemplosharedpreferences;

import android.app.Activity;
import android.content.Intent;
import android.content.SharedPreferences;
import android.os.Bundle;
import android.view.View;
import android.widget.EditText;
import android.widget.ImageButton;
import android.widget.TextView;
import android.widget.Toast;

import org.json.JSONException;
import org.json.JSONObject;

import java.io.IOException;

import consumer.UsuarioConsumer;
import pojo.Usuario;
import retrofit2.Call;
import retrofit2.Callback;
import retrofit2.Response;

public class TelaLogin extends Activity {
    private TextView tvCriarConta;
    private EditText etLogin, etSenha;
    private ImageButton btEntrar;
    private Usuario usuario;
    private SharedPreferences spLogin;
    private SharedPreferences.Editor editor;
    public static final String NOME_ARQUIVO = "arquivo_login";
    private UsuarioConsumer usuarioConsumer;


    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_tela_login);
        this.inicializaComponentes();

        if(this.verificaJaLogou()) {
            chamaTelaLogado();
        }

        this.btEntrar.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                usuario.setLogin(etLogin.getText().toString());
                usuario.setSenha(etSenha.getText().toString());
                chamaAutenticaWS(usuario.getLogin(),usuario.getSenha());

            }
        });

        this.tvCriarConta.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                // CHAMAR A TELA DE CADASTRO
                Intent itTelaCadastro = new Intent(TelaLogin.this, TelaCadastro.class);
                startActivity(itTelaCadastro);
                finish();
            }
        });




    }

    private void chamaTelaLogado() {
        Intent itTelaLogado = new Intent(TelaLogin.this, TelaLogado.class);
        Bundle parametros = new Bundle();
        parametros.putSerializable("usuario", usuario);
        itTelaLogado.putExtras(parametros);
        startActivity(itTelaLogado);
        finish();
    }


    private boolean verificaJaLogou() {
        boolean logou = false;
        String login = this.spLogin.getString("login", null);
        if(login!=null) {
            this.usuario.setLogin(login);
            logou = true;
        }
        return logou;
    }

    private Usuario chamaAutenticaWS(String login, String senha) {
        // IMPLEMENTAR CONSUMO DO WEB SERVICE PARA AUTENTICAÇÃO
        this.usuarioConsumer.postAutentica(login, senha).enqueue(new Callback<Usuario>() {
            @Override
            public void onResponse(Call<Usuario> call, Response<Usuario> response) {

                if(response.isSuccessful()) {
                    usuario = response.body();
                    editor.putString("login", usuario.getLogin());
                    editor.commit();
                    chamaTelaLogado();
                }else {
                    try {
                        //JSONObject(response.errorBody().string());
                        JSONObject jObjError = new JSONObject(response.errorBody().string());
                        Toast.makeText(TelaLogin.this, jObjError.getString("errorMessage"), Toast.LENGTH_LONG).show();
                    } catch (IOException e) {
                        e.printStackTrace();
                    } catch (JSONException e) {
                        e.printStackTrace();
                    }
                }
            }

            @Override
            public void onFailure(Call<Usuario> call, Throwable t) {

            }
        });


        return usuario;
    }




    private void inicializaComponentes() {
        this.etLogin = (EditText)findViewById(R.id.et_login);
        this.etSenha = (EditText)findViewById(R.id.et_senha);
        this.btEntrar = (ImageButton)findViewById(R.id.bt_entrar);
        this.usuario = new Usuario();
        this.spLogin = super.getApplicationContext().getSharedPreferences(NOME_ARQUIVO,MODE_APPEND);
        this.editor = this.spLogin.edit();
        this.usuarioConsumer = new UsuarioConsumer();
        tvCriarConta = (TextView)findViewById(R.id.tv_criar_conta);

    }


}
